@@ -1,7 +1,8 @@
 class PlottableMixin(object):
 
-    x_label: str = 'x'
+    x_label: str
     _label: str = None
+    y_label: str
 
     @property
     def label(self):
@@ -15,6 +16,11 @@ class PlottableMixin(object):
         self.x_label = x_label
         return self
 
+    def with_y_label(self, y_label: str) -> 'PlottableMixin':
+
+        self.y_label = y_label
+        return self
+
     def prepend_to_label(self, prepend: str):
 
         label = str(self) if self._label is None else self._label
@@ -26,3 +32,15 @@ class PlottableMixin(object):
 
         self._label = label
         return self
+
+
+class DiscretePlottableMixin(PlottableMixin):
+
+    x_label: str = 'k'
+    y_label: str = '$P(X = k)$'
+
+
+class ContinuousPlottableMixin(PlottableMixin):
+
+    x_label: str = 'x'
+    y_label: str = '$P(X = x)$'
