@@ -8,14 +8,14 @@ from probability.distributions.mixins.rv_mixins import RVS1dMixin, \
     Moment1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin, \
     Var1dMixin, Interval1dMixin, Support1dMixin, PDF1dMixin, \
     CDFContinuous1dMixin, SFContinuous1dMixin, PPFContinuous1dMixin, \
-    ISFContinuous1dMixin
+    ISFContinuous1dMixin, StatMixin
 
 
 class RVContinuous1dMixin(
     RVS1dMixin, Moment1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin,
     StD1dMixin, Var1dMixin, Interval1dMixin, Support1dMixin, PDF1dMixin,
     CDFContinuous1dMixin, SFContinuous1dMixin, PPFContinuous1dMixin,
-    ISFContinuous1dMixin, ContinuousPlottableMixin, object
+    ISFContinuous1dMixin, ContinuousPlottableMixin, StatMixin, object
 ):
 
     _distribution: rv_continuous
